
XEP-0405: MIX-PAM
=================

.. module:: slixmpp.plugins.xep_0405

.. autoclass:: XEP_0405
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0405.stanza
    :members:
    :undoc-members:

